@@ -1,10 +1,11 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  * gnome-printer-list.c
- * Copyright (C) 2003, Ximian, Inc.
+ * Copyright (C) 2003-2004, Ximian, Inc.
  *
  * Authors:
  *   Dave Camp <dave@ximian.com>
+ *   Jody Goldberg <jody@novell.com>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU Library General Public
@@ -26,18 +27,19 @@
 #include "gnome-printer-list.h"
 
 #include "printer-properties.h"
-#include "util.h"
 #include "view-queue.h"
 
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtkseparatormenuitem.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtkicontheme.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 
 #include <libgnomecups/gnome-cups-printer.h>
-#include <libgnomeui/gnome-icon-theme.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-macros.h>
+#include <libgnomecups/gnome-cups-ui-util.h>
+#include <libgnomecups/gnome-cups-permission.h>
 
 struct _GnomePrinterListDetails {
 	EggIconListItem *add_item;
@@ -49,30 +51,13 @@ struct _GnomePrinterListDetails {
 
 static void disconnect_printer (GnomePrinterList *list, GnomeCupsPrinter *printer);
 
-GNOME_CLASS_BOILERPLATE (GnomePrinterList, gnome_printer_list,
-                         GnomePrinterList,
-                         egg_icon_list_get_type ());
+G_DEFINE_TYPE (GnomePrinterList, gnome_printer_list, egg_icon_list_get_type ())
 
 static GdkPixbuf *
-load_icon (const char *icon_name)
+load_icon (char const *icon_name)
 {
-	GnomeIconTheme *theme;
-	const char *filename;
-	GdkPixbuf *pixbuf;
-	int base_size;
-	
-	theme = gnome_icon_theme_new ();
-
-	filename = gnome_icon_theme_lookup_icon (theme,
-						 icon_name,
-						 48,
-						 NULL,
-						 &base_size);
-	g_object_unref (theme);
-
-	pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-
-	return pixbuf;
+	return gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+		icon_name, 48, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
 }
 
 static void
@@ -287,7 +272,7 @@ gnome_printer_list_get_command_sensitivities (GnomePrinterList *list,
 	}
 	
 	if (delete) {
-		*delete = !new_printer_selected;
+		*delete = !new_printer_selected && gnome_cups_can_admin ();
 	}
 	
 	if (properties) {
@@ -558,18 +543,8 @@ icon_compare (EggIconList *icon_list,
 void
 gnome_printer_list_new_printer (GnomePrinterList *list)
 {
-        char *argv[] = { "gnome-cups-add", NULL };
-        GError *error;
-        
-        error = NULL;
-
-        g_spawn_async (NULL, argv, NULL, 
-                       G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error);
-
-        if (error) {
-		gnome_cups_error_dialog (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (list))), NULL, error);
-		g_error_free (error);
-        }
+	gnome_cups_spawn ("gnome-cups-add", 0, NULL,
+		TRUE, gtk_widget_get_toplevel (GTK_WIDGET (list)));
 }
 
 void
@@ -746,7 +721,7 @@ gnome_printer_list_selection_delete (GnomePrinterList *list)
 
 
 static void
-gnome_printer_list_instance_init (GnomePrinterList *list)
+gnome_printer_list_init (GnomePrinterList *list)
 {
 	GList *printer_names;
 	GList *l;
@@ -787,7 +762,7 @@ gnome_printer_list_destroy (GtkObject *object)
 {
 	GnomePrinterList *list;
 	GList *l;
-	
+
 	list = GNOME_PRINTER_LIST (object);
 
 	for (l = list->details->printers; l != NULL; l = l->next) {
@@ -802,7 +777,7 @@ gnome_printer_list_destroy (GtkObject *object)
 		list->details->new_printer_notify = 0;
 	}
 	
-        GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+        GTK_OBJECT_CLASS (gnome_printer_list_parent_class)-> destroy, (object);
 }
 
 static void
@@ -816,8 +791,6 @@ gnome_printer_list_finalize (GObject *object)
 static void
 gnome_printer_list_class_init (GnomePrinterListClass *class)
 {
-	parent_class = g_type_class_peek_parent (G_OBJECT_CLASS (class));
-
 	GTK_OBJECT_CLASS (class)->destroy = gnome_printer_list_destroy;
 	G_OBJECT_CLASS (class)->finalize = gnome_printer_list_finalize;
 }
